[![licence-apache20]](/LICENCE.txt)


Redocly OpenAPI Lint Hook for Pre-Commit
========================================

This [Pre-Commit](https://pre-commit.com/) hook lints OpenAPI specifications with Redocly's 
OpenAPI-CLI tool in a Docker container.

Docker is an extremely useful tool that *all* developers should understand and make use of.  
It is extremely easy to install on major operating systems and allows development tools and 
their dependencies to be isolated from the system regardless of the runtime used.

> **Note:**
> The OpenAPI-CLI tool is Node.js based, and if your project uses Node.js you may be able to 
> avoid the dependency on Docker by adding a "local" hook to your pre-commit configuration 
> instead of this hook.  That is outside the scope of this project, please read the 
> pre-commit documentation.


Usage
-----

| Requirements |
| ------------ |
| `pre-commit` |
| `docker`     |

Add this hook to a `.pre-commit-config.yaml` configuration:

```yaml
- repo: https://code.kodo.org.uk/dom/pre-commit-oas-lint
  rev: v0.1
  hooks:
  - id: openapi-lint
```


Configuration
-------------

### File Matching

By default the hook lints any YAML or JSON file matching one of the patterns:

- `*.openapi.json`
- `*.openapi.yaml`
- `*.openapi.yml`
- `openapi.json`
- `openapi.yaml`
- `openapi.yml`

To specify alternative names add a replacement regular expression to the 'files' item of 
a hook configuration:

```yaml
- repo: https://code.kodo.org.uk/dom/pre-commit-oas-lint
  rev: <required-revision-here>
  hooks:
  - id: openapi-lint
    files: "oas\\.json$"
```


### Command Line Arguments

The default command line options select a cleaner output than the default.  The only options 
you are ever likely to provide yourself are:

| Option           | Description                                                 |
| ---------------- | ----------------------------------------------------------- |
| `--config`       | Used to specify an alternative path to a configuration file |
| `--format`       | Specify an alternative output format                        |
| `--max-problems` | Limit the amount of output from the hook                    |

Other options are best specified through the [Redocly configuration file][].

> **Note:**
> When providing an alternative argument list, the original (with `--format=stylish`) is 
> lost; you will need to include it to have the same output.

```yaml
- repo: https://code.kodo.org.uk/dom/pre-commit-oai-lint
  rev: <required-revision-here>
  hooks:
  - id: openapi-lint
    args: [--format=stylish, --max-problems=10]
```

---

[licence-apache20]:
  https://img.shields.io/badge/Licence-Apache--2.0-blue.svg
  "Licence: Apache License 2.0"

[Redocly configuration file]:
  https://redoc.ly/docs/cli/guides/lint/#lint-configuration
  "Redocly OpenAPI-CLI lint configuration"
